@@ -7,7 +7,7 @@ const process = require("process");
 const path = require("path");
 const fs = require("fs");
 
-const binaryDir = path.join('dist', 'bin', `${os.platform}-${os.arch}`, 'aws-crt-nodejs.node');
+const binaryDir = path.join('dist', 'bin', `${os.platform()}-${os.arch()}`, 'aws-crt-nodejs.node');
 if (fs.existsSync(binaryDir)) {
     // Don't continue if the binding already exists (unless --rebuild is specified)
     process.exit(0);
